%%%%%%%% PLOT CREDIBLE REGION AND TIME CURVES  %%%%%%%%%%%%%%%%%%%

%%-----------------------------------------------------------------
%%%%%%%%%%%%%% PLOT 100(1-alpha)% CREDIBLE REGION OF THE PDF %%%%%%%%%%%%%%%%%%
if plotpdf==1
    par.td=linspace(0,Tf,nd); %% time points
    sig=b*par.Y0; par.sig=sig; %% b: relative Gaussian noise level

    if samplepdf==0
        %%% load sampled PDF
        load(['samples\sample_model' num2str(model) ])
        states=transform(states); %% transform to logspace
    end
    
    %%%%% take a sample of the PDF
    states_s=zeros(nsample,n);
    for j2=1:nsample
        j3=ceil(rand*size(states,1)); %% select random state number
        states_s(j2,:)=states(j3,:);
    end
    
    %% compute log probability of states
    logprob=zeros(size(states_s),1);
    for j=1:size(states_s)
        logprob(j,1)=logposterior(states_s(j,:),par);
    end
    ind=round((1-alph)*size(states_s,1)); % number of par values to be discarded
    [val ix]=sort(-2*logprob,'descend'); %% sort probabilities
    
    %% discard least credible parameter values
    %% states_alpha defines the credible parameter region as in, e.g., Fig 2B
    states_alpha=states_s; states_alpha(ix(1:ind),:)=[];
        
    
    figure;
    if ny==1; nt=1; nb=1; else nt=ceil(sqrt(length(a0)+1)); nb=ceil(sqrt(length(a0)));end
    for j=1:length(a0)-1
        subplot(nt,nb,j)
        loglog(backtransform(states_alpha(:,j)),backtransform(states_alpha(:,j+1)),'*'); hold on
        loglog(backtransform(a0(j)),backtransform(a0(j+1)),'r*');
        xlabel(['\theta_{' num2str(j) '}'],'FontWeight','bold','Fontsize',12);
        ylabel(['\theta_{' num2str(j+1) '}'],'FontWeight','bold','Fontsize',12);
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%-----------------------------------------------------------------
%%%%%%%%%%%%%%% PLOT TIME CURVES %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if plotdyn==1
    fc=[1 1 0]; %% color
    par.td=linspace(0,Tf,nd2); %new time series
    if model==1 
        figure;
        par.preddynamics=1;
        x0=z0(2); 
        if LCA==1 %% only for model 1
            for j=1:n
                ap=10.^a0; am=ap;
                ap(j)=ap(j)*(1.01); am(j)=am(j)*(1-0.01);                 
                [time,Y0]=makeY(a0,x0,par);                
                [time,Ysimp]=makeY(log10(ap),x0,par);
                [time,Ysimm]=makeY(log10(am),x0,par);
                %% dy/d(theta)
                dydth(:,j)=(Ysimp(2:end,1)-Ysimm(2:end,1))/(ap(j)-am(j));
            end
            [time,Y]=makeY(a0,x0,par);
            Ymean=Y; dy(1)=0; Ymax(1)=Ymean(1); Ymin(1)=Ymean(1);
            for kt=2:length(time)
                dy(kt)=dydth(kt-1,:)*inv(par.H)*dydth(kt-1,:)';
                Ymax(kt)=Y(kt)+1.96*sqrt(dy(kt));
                Ymin(kt)=max(1e-16,Y(kt)-1.96*sqrt(dy(kt)));
                Q_dist(kt)=log2(Ymin(kt)/Y(kt));
            end
            
            Q_95=sum(Q_dist.^2)/(nd2-1);
            disp(['Q_95= ' num2str(Q_95)])
            
        else %%
            
            %%% load sample
            load(['samples\sample_model' num2str(model) ])
            states=transform(states); %% transform to logspace

            %%%%% take a sample of the PDF
            states_s=zeros(nsample,n);
            for j2=1:nsample
                j3=ceil(rand*size(states,1)); %% select random state number
                states_s(j2,:)=states(j3,:);
            end            
                        
            [time,Y0]=makeY(a0,x0,par);
            sig=b*Y0; par.sig=sig; %% b: relative Gaussian noise level
            Y=zeros(size(states_s,1),nd2);
            for j2=1:size(states_s,1)  
                [time,Ysim]=makeY(states_s(j2,:),x0,par);
                Y(j2,:)=Ysim(:,1)';
            end
            
            ind2=round((1-alph)*nsample/2);
            for t2=1:size(par.td,2)                
                [Yval iy]=sort(Y(:,t2),'descend'); %% largest values first
                Yval(end-ind2:end)=[]; Yval(1:ind2)=[];
                Ymax(t2)=max(Yval); Ymin(t2)=min(Yval); Ymean(t2)=mean(Yval);
            end
        end
                
        semilogy(time, Ymax, 'Color', fc); hold on
        semilogy(time, Ymin, 'Color', fc); hold on
        semilogy(time, Ymean, '--'); hold on
        
        fill([time' fliplr(time')],[Ymax fliplr(Ymin)],fc)
        if z0(1)==z0(2) 
            errorbar(time,Y0,sig,'x','LineWidth',2);
        end
        
        ylim([1e-2 inf]);
        xlabel('t','FontSize',16,'FontWeight','bold');
        ylabel('y','FontSize',16,'FontWeight','bold');
        set(gca,'XTick',linspace(0,5,6),'FontSize',16);

    elseif model>1
                        
        [time,Y0]=makeY(a0,x0,par);
        Y2=zeros(nsample,nd2);
        ind2=round((1-alph)*nsample/2);
        figure; nt=ceil(sqrt(ny));
        for k3=1:ny % ny outputs
            for j2=1:nsample
                [time,Y]=makeY(states_s(j2,:),x0,par);
                Y2(j2,:)=Y(:,k3)';
            end
            for t2=1:size(par.td,2)
                %% sort Y values at each time point and discard smalles
                %% and largest values
                [Yval iy]=sort(Y2(:,t2),'descend');
                Yval(end-ind2:end)=[]; Yval(1:ind2)=[];
                Ymax(t2)=max(Yval); Ymin(t2)=min(Yval);
            end
            
            subplot(nt,nt,k3)
            semilogy(time, Ymax, 'Color', fc); hold on
            semilogy(time, Ymin, 'Color', fc); hold on
            fill([time' fliplr(time')],[Ymax fliplr(Ymin)],fc)
            xlabel('t','FontSize',12,'FontWeight','bold');
            ylabel('y','FontSize',12,'FontWeight','bold');
            xlim([0 Tf]);
            set(gca,'XTick',linspace(0,Tf,2),'FontSize',12);
            
        end
    end
end
%% plot Gelman statistic
if Gelman==1
    figure; tg=linspace(0,nit*nchain,size(R,1));
    for j=1:n
        subplot(round(sqrt(n)),ceil(sqrt(n)),j)
        plot(tg,R(:,j)); hold on;
        plot(tg,1.2*ones(1,size(R,1)),'--'); ylim([0.5 1.5]);
        if j==1; xlabel('Iterations'); ylabel('Scale reduction '); end
        title(['\theta_{' num2str(j) '}'])
    end
end

if plot_Q==1
    figure;
    for model=modelset
        for j=1: length(Q_alpha{model})
            if Q_alpha{model}(j) < 1; cl='b'; else cl='r'; end %% blue and red
            semilogy(model,Q_alpha{model}(j),'*','Color',cl,'LineWidth',1); hold on
            plot(modelset,ones(1,length(modelset)),'r--'); hold on
        end
    end
    xlim([modelset(1)*.9 modelset(end)*1.05]); ylim([1e-3 1e3]);
    xticklabel_rotate(modelset,45, {modellabel{modelset}},'FontSize',12)
    set(gca,'YTick',logspace(-3,3,7),'FontSize',12);
    yl=ylabel('Q_{0.95}','FontSize',14); 
end

